@@ -380,6 +380,26 @@ class LocalPorvider(BaseProvider):
         """
         return TDP.get_daily_indexweight(instruments, **kws)
 
+    def get_daily_hs300weight(self, **kws):
+        """
+            table_name: 'AIndexFreeWeight'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: stockcode, weight
+        """
+        instruments = "000300.SH"
+        return TDP.get_daily_indexweight(instruments, **kws)
+
+    def get_daily_csi500weight(self, **kws):
+        """
+            table_name: 'AIndexFreeWeight'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: stockcode, weight
+        """
+        instruments = "000905.SH"
+        return TDP.get_daily_indexweight(instruments, **kws)
+
     def index_member(self, indexcode: str, start_date: str = None, end_date: str = None):
         """
             table_name: 'AIndexMembers'
